#include <linuxmt/types.h>

int chr_dev_init()
{
	/* rs_init(); */
	/* lp_init(); */
	xtk_init();
}
